@@ -117,6 +117,7 @@
   int ctcomp = 0;
   int isdupe = 0; //0 if nodupe -- for auto qso b4 (LZ3NY)
   int nob4 = 0;   // allow auto b4
+  int ignoredupe = 0;
   int noautocq = 0;
   int emptydir = 0;
   int verbose = 0;
@@ -302,7 +303,7 @@ int commentfield = 0;
   int multlist = 0;
   int max_multipliers;
   int mult_bands[MAX_MULTS];
-  char callmasterarray[MAX_CALLMASTER][9];
+  char callmasterarray[MAX_CALLMASTER][14];
   char callmaster_result[50][9];
   long int max_callmastercalls;
   int callareas[20];
@@ -334,15 +335,10 @@ int commentfield = 0;
   	pid_t pid;
 	struct tm *time_ptr;
 
-
-//  char logline0[81] = "";
-//  char logline1[81] = "";
-//  char logline2[81] = "";
-//  char logline3[81] = "";
-//  char logline4[240] = "";
   char qrg_string[8];
   float freq;
   float mem;
+  int logfrequency = 0;
   int rit;
   int trx_control = 0;
   int showfreq = 0;
