@@ -163,8 +163,10 @@ int readcalls(void)
 			    wysiwyg_multi == 1 ||
 			    arrlss == 1|| 
 			    serial_section_mult == 1||
+				serial_grid4_mult == 1 ||
 			    sectn_mult == 1 ||
-			    ((dx_arrlsections == 1) && ((countrynr == w_cty) || (countrynr == ve_cty)))){
+			    ((dx_arrlsections == 1) && ((countrynr == w_cty) || (countrynr == ve_cty))))
+			    {
 
   				multbuffer[0] = '\0';
 
@@ -178,13 +180,13 @@ int readcalls(void)
 
 					multbuffer[3]='\0';
 
-				} else if (serial_section_mult == 1)  {
+				} else if (serial_section_mult == 1 )  {
 					
 					tt = 0;
 
 					memset (multbuffer, 0, 39);
 
-					for (t = 56; t < 68; t++){
+					for (t = 54; t < 64; t++){
 						if (inputbuffer[t] >='A' && inputbuffer[t] <= 'Z')
 						{
 							multbuffer[tt] = inputbuffer[t];
@@ -192,7 +194,15 @@ int readcalls(void)
 						}
 					}
 
-
+				} else if (serial_grid4_mult == 1) {
+				
+					memset (multbuffer, 0, 39);
+					
+					for (t = 0; t < 4; t++){
+					
+						multbuffer[t] = inputbuffer[t+59];
+					}
+					
 				} else {
 
 					strncpy(multbuffer, inputbuffer+54, 10);       // normal case
@@ -497,7 +507,9 @@ int readcalls(void)
 	if ((arrlss == 1) &&(total == 0) )  multcount=0;
 
 
-	if (((serial_section_mult == 1)|| (sectn_mult == 1)) && multarray_nr == 1){               // correction ......
+	if (((serial_section_mult == 1)
+//		|| (serial_grid4_mult == 1)
+		|| (sectn_mult == 1)) && multarray_nr == 1){               // correction ......
 		mults[1][0] = '\0';
 		mult_bands[1] = 0;
 	}  else if  (serial_section_mult == 1 && multarray_nr > 1)
